%------------------- LineShapeKin SETUP -----------------------------
%-- version 3.0 
%
% 3/11/08
% Written by Evgenii Kovrigin, Medical College of Wisconsin
%
% 3/29/08 - data localization changed


% NOTE:  In this run I have inserted optimized values for w0_B into 
%             manual_w0.txt files (I copied spectral data into a local folder here)
%            Now I will fit for Kd and Koff

global   YES NO ;

%% Read definitions of the fitting model from this file
model_setup;

% Define enzyme concentration at each titration point. If your addition of
% ligand did not change volume - use the same number for all points
Ptotal = [ 530 530 530 530 530 530 530 530 530 530]*1.0e-6;  % M

% Total Ligand/Protein ratio at each titration point
LPratio = [ 0 0.0812 0.162 0.325 0.487 0.649 0.812 0.974 1.14 1.3];

%-- Temperatures (only used with temperature-dependent model. Otherwise -
%     ignored.
T =  ones(1,length(Ptotal)) *298;



% NOTE: If you need to exclude any points for a SPECIFIC residue from
% fitting (due to overlap) - edit  'titration_points.txt' file in the
% residue data folder. 


%--- Path do Sparky data folder
Sparky_data_path='Data_for_MatLab';

%--- Folder where to save results
results_path='results'; 


%-- Enter here a list of residues to use ----

% -- cut-and-paste them from  Data_for_Matlab/matlab.peaklist ---
resnames =   {  'Y92_x_w1',   'T70_x_w1',  'S123_x_w1', 'S123_x_w2', 'H12_x_w2'};
%resnames =   {  'Y92_x_w1',    'S123_x_w1', 'S123_x_w2'};
%resnames =   {   'S123_x_w1', 'S123_x_w2'};







%% Mode of operation : 

%project_name='simulation';  %-- calculate titration profile using provided R2 and w0 values

%project_name='just display data'; %- only do normalization and plotting of raw data

project_name= 'single'; %- lets you fit just one of them
                                        %           in this case set residue_number=... desired number
                                        %           in all other cases this variable is disregarded
residue_number=4   ; %--- particular residue in 'resnames' to look at
                    %  (read only in 'simulation',  'single' or 'just display data' mode) 

                                        
                                        
                                        
%project_name= 'individual' ; %- fit all of them individually to individual Koffs 

%project_name= 'global';%- fit all of them to one Koff







% -- Normalization by total integral of the trace: 
%           It requires that peak tails go down to baseline ON BOTH SIDES,
%           otherwise incorrect results will be obtained: first and last points of the trace are taken as 
%           constant baseline estimate to subtract baseline.
Normalization='integration' ; 

%Integration_mode='rectangular';   %-- integration by rectangular formula
Integration_mode='simpson';   %-- integration by Simpson's formula NOTE:





% 2. ---- Baseline correction ---  
%  Use ONLY when your peak falls off to the noise floor AT LEAST on one
%  side
%Baseline_Correction=YES; 
Baseline_Correction=NO;

% 3. --- starting line width in fitting of initial raw data for
%           determination of positions and relaxation rates of end points
Line_Width_0=50;


% -- Plotting option for fitting or simulation results
Stacked_Plot=YES;   %--- YES  to display the titration series stacked rather than overlayed
Percent_Shift=75 ;   %-- percentage of the peak height for shifting next trace up. Applicable 
                                %    if  Stacked_Plot=YES

% 5. -- Before starting, make sure that Matlab knows where the code is:
%   use File : Set Path and Add Folder 



% 6. ---- NOW YOU ARE READY. TYPE IN 'main' AT A MATLAB COMMAND LINE -----

