function [p, K, R2_vector, v_vector]=rate_matrix(beta, x)
%------------------- LineShapeKin RATE_MATRIX -----------------------------
%-- version 3.0 
%
% 3/17/08
% Written by Evgenii Kovrigin, Medical College of Wisconsin
%
% This function builds a rate (K) matrix for the spin exchange between the
% sites corresponding to the equation:  
%      P+L=PL, Kd=k2/k1, where k1=kon*[L], k2=Koff
%
%   NOTES:    Here we will  fit for Kd, Koff, w0_B but NOT the scaling
%   factor



global B_vector Model  X_columns 


  
%-- extract variable parameters

Kd = beta(B_vector.Kd);   

koff=beta(B_vector.Koff);

LPratio_corr=beta(B_vector.LPratio_corr);



%-- extract experimental parameters:

Ptot = x(X_columns.Ptotal);    
Ltot = Ptot*x(X_columns.LPratio) * LPratio_corr;  





%% Analytical solution for [L] out of 
%
%   Kd = [P][L]/[PL]
%
a=1;
b=-(Ptot+Ltot+Kd);
c=Ptot*Ltot;
sola=-b/(2*a);
solb=sqrt(b^2-(4*a*c))/(2*a);
sol1=[(sola+solb) (sola-solb)];
Peq=max(Ptot-sol1); %-- get positive solution
PLeq=Ptot-Peq;
Leq=Ltot-PLeq;

% Equilibrium mole fractions of species containting P 
p=[Peq/Ptot,PLeq/Ptot];

%-- relationships of true constants
kon=koff/Kd;

% K matrix elements
kab=kon*Leq;
kba=koff;

K=[-kab,kba;kab,-kba];


%-- prepare relaxation rates and frequencies for the individual species
 R2_vector=[ x(X_columns.R2A),  x(X_columns.R2B) ];  
 %v_vector=[ x(X_columns.wA),    x(X_columns.wB)   ];  
v_vector=[ x(X_columns.wA),    beta(B_vector.w0_B)   ];  

% %-- exchange mode determination
% disp(sprintf('L/P=%.3f    [L]=%.1e M,  K1=%.1e /s,  K2,off=%.1e /s', ...
%     x(X_columns.LPratio), Leq, kab, kba));

