function [figure1, figure2] = create_titration_figure(figure_title, titration_points, P_current, V_current, LP_current, PLeq, Peq, Leq)
% Plot experimental design data
N=length(titration_points);

%% Create figure of all quantities as a function of titration point number
figure1 = figure('XVisual',...
    '0x22 (TrueColor, depth 24, RGB mask 0xff0000 0xff00 0x00ff)',...
    'Color',[0.9412 0.9412 0.9412]);

%%  Protein concentration graph
axes1 = axes('Parent',figure1,'YMinorTick','on','XMinorTick','on','YGrid','on',...
    'XTick', 0:1:N ,...
    'XGrid','on',...
    'Position',[0.09457 0.5789 0.3883 0.3102],...
    'FontSize',12);
% Uncomment the following line to preserve the Y-limits of the axes
ylim([0 max(P_current)]);
box('on');
hold('all');

% Create plot
plot(titration_points,P_current,'Parent',axes1,'Marker','.','Color',[0 0 0],'MarkerSize',5,'Marker','o','LineWidth',1);

% Create xlabel
%xlabel('Titration point','FontSize',14);

% Create ylabel
ylabel('C_{receptor}, M','FontSize',14);

% Create title
title('Dilution of a receptor','FontWeight','bold','FontSize',14);


%% Ligand/Receptor ratio graph
% Create axes
axes2 = axes('Parent',figure1,'YMinorTick','on','XMinorTick','on','YGrid','on',...
    'XTick', 0:1:N ,...
    'XGrid','on',...
    'Position',[0.09106 0.08083 0.3902 0.3703],...
    'FontSize',12);
% Uncomment the following line to preserve the Y-limits of the axes
ylim([0 max(LP_current)]);
box('on');
hold('all');

% Create plot
plot(titration_points,LP_current,'Parent',axes2,'Marker','.','Color',[0 0 0],'MarkerSize',5,'Marker','o','LineWidth',1);

% Create xlabel
xlabel('Titration point','FontSize',14);

% Create ylabel
ylabel('Ligand/Protein (mol/mol)','FontSize',14);

% Create title
title('Ligand/receptor ratio','FontWeight','bold','FontSize',14);


%% Complex formation graph
% Create axes
axes3 = axes('Parent',figure1,'YMinorTick','on','XMinorTick','on','YGrid','on',...
    'XTick', 0:1:N ,...
    'XGrid','on',...
    'Position',[0.5967 0.08835 0.387 0.3628],...
    'FontSize',12);
% Uncomment the following line to preserve the Y-limits of the axes
ylim([0 max(Peq)]);
box('on');
hold('all');

% Create plot
plot(titration_points,PLeq,'Parent',axes3,'Marker','.','Color',[0 0 0],'DisplayName','[RL]','MarkerSize',5,'Marker','o','LineWidth',1); hold on;
plot(titration_points,Peq,'Parent',axes3,'Marker','.','Color',[1 0 0],'DisplayName','[R]','MarkerSize',5,'Marker','o','LineWidth',1); hold on;
plot(titration_points,Leq,'Parent',axes3,'Marker','.','Color',[0 0 1],'DisplayName','[L]','MarkerSize',5,'Marker','o','LineWidth',1); hold on;

% Create xlabel
xlabel('Titration point','FontSize',14);

% Create ylabel
ylabel('Equilibrium concentration, M','FontSize',14);

% Create title
title('Complex formation','FontWeight','bold','FontSize',14);

legend1 = legend(axes3,'show');
set(legend1,'Position',[0.8551 0.5239 0.1323 0.1049],'FontSize',10);



%% Sample volume graph
% Create axes
axes4 = axes('Parent',figure1,'YMinorTick','on','XMinorTick','on','YGrid','on',...
    'XTick', 0:1:N ,...
    'XGrid','on',...
    'Position',[0.6016 0.5752 0.2415 0.3139],...
    'FontSize',12);
% Uncomment the following line to preserve the Y-limits of the axes
ylim([0 max(V_current)]);
box('on');
hold('all');

% Create plot
plot(titration_points,V_current,'Parent',axes4,'Marker','.','Color',[0 0 0],'MarkerSize',5,'Marker','o','LineWidth',1);

% Create xlabel
%xlabel('Titration point','FontSize',14);

% Create ylabel
ylabel('Total volume, L','FontSize',14);

% Create title
title('Total sample volume','FontWeight','bold','FontSize',14);


%% Annotation
% Create textbox
annotation(figure1,'textbox',[0.1061 0.9648 0.8266 0.04323],...
    'String',{figure_title},...
    'HorizontalAlignment','center',...
    'FontWeight','light',...
    'FontSize',20,...
    'FitBoxToText','off',...
    'LineStyle','none');




%% Create normalized figure versus L/P ratio
figure2 = figure('XVisual',...
    '0x22 (TrueColor, depth 24, RGB mask 0xff0000 0xff00 0x00ff)',...
    'Color',[0.9412 0.9412 0.9412]);

% Create axes
axes3 = axes('Parent',figure2,'YMinorTick','on','XMinorTick','on','YGrid','on',...
    'XGrid','on',...
    'Position',[0.13 0.2089 0.775 0.7161],...
    'FontSize',12);
% Uncomment the following line to preserve the Y-limits of the axes
ylim([0 1]);
box('on');
hold('all');


% Create plot of normalized values
plot(LP_current,PLeq./P_current,'Parent',axes3,'Marker','.','Color',[0 0 0],'DisplayName','[RL]/C_{total,R}','MarkerSize',10,'Marker','o','LineWidth',1); hold on;
plot(LP_current,Peq./P_current,'Parent',axes3,'Marker','.','Color',[1 0 0],'DisplayName','[R]/C_{total,R}','MarkerSize',10,'Marker','o','LineWidth',1); hold on;
plot(LP_current,Leq./P_current,'Parent',axes3,'Marker','.','Color',[0 0 1],'DisplayName','[L]/C_{total,R}','MarkerSize',10,'Marker','o','LineWidth',1); hold on;

% Create xlabel
xlabel('Ligand/Receptor, (mol/mol)','FontSize',14);

% Create ylabel
ylabel('Mole fraction of Receptor forms','FontSize',14);

legend1 = legend(axes3,'show');
set(legend1,'Orientation','horizontal','Position',[0.1557 0.02336 0.7262 0.06597],'FontSize',14);


% Create title
title('Complex formation','FontWeight','bold','FontSize',14);




